Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2169)

Unified Diff: chrome/browser/views/bookmark_bar_view.cc

Issue 71003: Merge 13106 - Fixes regression in dragging bookmark bar. The bookmark bar wou... (Closed) Base URL: svn://chrome-svn.corp.google.com/chrome/branches/172/src/
Patch Set: Created 11 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/views/bookmark_bar_view.cc
===================================================================
--- chrome/browser/views/bookmark_bar_view.cc (revision 13559)
+++ chrome/browser/views/bookmark_bar_view.cc (working copy)
@@ -1157,8 +1157,9 @@
int BookmarkBarView::GetDragOperations(View* sender, int x, int y) {
if (size_animation_->IsAnimating() ||
- size_animation_->GetCurrentValue() == 0) {
- // Don't let the user drag while animating open or we're closed. This
+ (size_animation_->GetCurrentValue() == 0 && !OnNewTabPage())) {
+ // Don't let the user drag while animating open or we're closed (and not on
+ // the new tab page, on the new tab page size_animation_ is always 0). This
// typically is only hit if the user does something to inadvertanty trigger
// dnd, such as pressing the mouse and hitting control-b.
return DragDropTypes::DRAG_NONE;
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698